fnss.traffic.trafficmatrices.validate_traffic_matrix — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.traffic.trafficmatrices.validate_traffic_matrix

`validate_traffic_matrix`(topology, traffic_matrix, validate_load=False)

  Validate whether a given traffic matrix and given topology are compatible.

  Returns True if they are compatible, False otherwise

  This validation includes validating whether the origin-destination pairs of the traffic matrix are coincide with or are a subset of the origin-destination pairs of the topology. Optionally, this function can verify if the volumes of the traffic matrix are compatible too, i.e. if at any time, no link has an utilization greater than 1.0.

  Parameters : | topology : topology The topology agains which the traffic matrix is validated tm : TrafficMatrix or TrafficMatrixSequence The traffic matrix (or sequence of) to be validated validate_load : bool, optional Specify whether load compatibility has to be validated or not. Default value is False
  Returns : | is_valid : bool True if the topology and the traffic matrix are compatible, False otherwise

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »